@@ -63,9 +63,11 @@ class Utilities(script_utilities.Utilities):
         self._isLink = {}
         self._isNonNavigablePopup = {}
         self._isNonEntryTextWidget = {}
+        self._isUselessImage = {}
         self._inferredLabels = {}
         self._text = {}
         self._tag = {}
+        self._treatAsDiv = {}
         self._currentObjectContents = None
         self._currentSentenceContents = None
         self._currentLineContents = None
@@ -99,8 +101,10 @@ class Utilities(script_utilities.Utilities):
         self._isLink = {}
         self._isNonNavigablePopup = {}
         self._isNonEntryTextWidget = {}
+        self._isUselessImage = {}
         self._inferredLabels = {}
         self._tag = {}
+        self._treatAsDiv = {}
         self._cleanupContexts()
 
     def clearContentCache(self):
@@ -130,7 +134,15 @@ class Utilities(script_utilities.Utilities):
             return None
 
         roles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB, pyatspi.ROLE_EMBEDDED]
-        isDocument = lambda x: x and x.getRole() in roles
+
+        def isDocument(x):
+            try:
+                return x and x.getRole() in roles
+            except:
+                msg = "WEB: Exception getting role for %s" % x
+                debug.println(debug.LEVEL_INFO, msg)
+                return False
+
         if isDocument(obj):
             return obj
 
@@ -154,7 +166,13 @@ class Utilities(script_utilities.Utilities):
     def documentFrame(self, obj=None):
         isShowing = lambda x: x and x.getState().contains(pyatspi.STATE_SHOWING)
 
-        windows = [child for child in self._script.app]
+        try:
+            windows = [child for child in self._script.app]
+        except:
+            msg = "WEB: Exception getting children for app %s" % self._script.app
+            debug.println(debug.LEVEL_INFO, msg)
+            windows = []
+
         if orca_state.activeWindow in windows:
             windows = [orca_state.activeWindow]
 
@@ -186,13 +204,21 @@ class Utilities(script_utilities.Utilities):
         try:
             state = obj.getState()
         except:
+            msg = "WEB: Exception getting state for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
             return
 
         orca.setLocusOfFocus(None, obj, notifyScript=False)
         if state.contains(pyatspi.STATE_FOCUSABLE):
             try:
                 obj.queryComponent().grabFocus()
+            except NotImplementedError:
+                msg = "WEB: %s does not implement the component interface" % obj
+                debug.println(debug.LEVEL_INFO, msg)
+                return
             except:
+                msg = "WEB: Exception grabbing focus on %s" % obj
+                debug.println(debug.LEVEL_INFO, msg)
                 return
 
         text = self.queryNonEmptyText(obj)
@@ -448,6 +474,8 @@ class Utilities(script_utilities.Utilities):
         except NotImplementedError:
             pass
         except:
+            msg = "WEB: Exception getting range extents for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
             return [0, 0, 0, 0]
 
         role = obj.getRole()
@@ -456,12 +484,24 @@ class Utilities(script_utilities.Utilities):
            and parentRole in [pyatspi.ROLE_COMBO_BOX, pyatspi.ROLE_LIST_BOX]:
             try:
                 ext = obj.parent.queryComponent().getExtents(0)
+            except NotImplementedError:
+                msg = "WEB: %s does not implement the component interface" % obj.parent
+                debug.println(debug.LEVEL_INFO, msg)
+                return [0, 0, 0, 0]
             except:
+                msg = "WEB: Exception getting extents for %s" % obj.parent
+                debug.println(debug.LEVEL_INFO, msg)
                 return [0, 0, 0, 0]
         else:
             try:
                 ext = obj.queryComponent().getExtents(0)
+            except NotImplementedError:
+                msg = "WEB: %s does not implement the component interface" % obj
+                debug.println(debug.LEVEL_INFO, msg)
+                return [0, 0, 0, 0]
             except:
+                msg = "WEB: Exception getting extents for %s" % obj
+                debug.println(debug.LEVEL_INFO, msg)
                 return [0, 0, 0, 0]
 
         return [ext.x, ext.y, ext.width, ext.height]
@@ -1053,8 +1093,8 @@ class Utilities(script_utilities.Utilities):
             return objects
 
         firstObj, firstStart, firstEnd, firstString = objects[0]
-        if extents[2] == 0 and extents[3] == 0:
-            extents = self.getExtents(obj, firstStart, firstEnd)
+        if (extents[2] == 0 and extents[3] == 0) or self.isMath(firstObj):
+            extents = self.getExtents(firstObj, firstStart, firstEnd)
 
         lastObj, lastStart, lastEnd, lastString = objects[-1]
         prevObj, pOffset = self.findPreviousCaretInOrder(firstObj, firstStart)
@@ -1102,31 +1142,37 @@ class Utilities(script_utilities.Utilities):
         if obj is None:
             obj, offset = self.getCaretContext()
 
-        msg = "INFO: Current context is: %s, %i" % (obj, offset)
+        msg = "WEB: Current context is: %s, %i" % (obj, offset)
         debug.println(debug.LEVEL_INFO, msg)
 
         if obj and self.isZombie(obj):
-            msg = "INFO: Current context obj %s is zombie" % obj
+            msg = "WEB: Current context obj %s is zombie" % obj
             debug.println(debug.LEVEL_INFO, msg)
 
         line = self.getLineContentsAtOffset(obj, offset, layoutMode, useCache)
-        msg = "INFO: Line contents for %s, %i: %s" % (obj, offset, line)
+        msg = "WEB: Line contents for %s, %i: %s" % (obj, offset, line)
         debug.println(debug.LEVEL_INFO, msg)
 
         if not (line and line[0]):
             return []
 
         firstObj, firstOffset = line[0][0], line[0][1]
-        msg = "INFO: First context on line is: %s, %i" % (firstObj, firstOffset)
+        msg = "WEB: First context on line is: %s, %i" % (firstObj, firstOffset)
         debug.println(debug.LEVEL_INFO, msg)
 
         obj, offset = self.previousContext(firstObj, firstOffset, True)
-        msg = "INFO: Previous context is: %s, %i" % (obj, offset)
+        if not obj and firstObj:
+            msg = "WEB: Previous context is: %s, %i. Trying again." % (obj, offset)
+            debug.println(debug.LEVEL_INFO, msg)
+            self.clearCachedObjects()
+            obj, offset = self.previousContext(firstObj, firstOffset, True)
+
+        msg = "WEB: Previous context is: %s, %i" % (obj, offset)
         debug.println(debug.LEVEL_INFO, msg)
 
         contents = self.getLineContentsAtOffset(obj, offset, layoutMode, useCache)
         if not contents:
-            msg = "INFO: Could not get line contents for %s, %i" % (obj, offset)
+            msg = "WEB: Could not get line contents for %s, %i" % (obj, offset)
             debug.println(debug.LEVEL_INFO, msg)
             return []
 
@@ -1136,15 +1182,15 @@ class Utilities(script_utilities.Utilities):
         if obj is None:
             obj, offset = self.getCaretContext()
 
-        msg = "INFO: Current context is: %s, %i" % (obj, offset)
+        msg = "WEB: Current context is: %s, %i" % (obj, offset)
         debug.println(debug.LEVEL_INFO, msg)
 
         if obj and self.isZombie(obj):
-            msg = "INFO: Current context obj %s is zombie" % obj
+            msg = "WEB: Current context obj %s is zombie" % obj
             debug.println(debug.LEVEL_INFO, msg)
 
         line = self.getLineContentsAtOffset(obj, offset, layoutMode, useCache)
-        msg = "INFO: Line contents for %s, %i: %s" % (obj, offset, line)
+        msg = "WEB: Line contents for %s, %i: %s" % (obj, offset, line)
         debug.println(debug.LEVEL_INFO, msg)
 
         if not (line and line[0]):
@@ -1155,16 +1201,22 @@ class Utilities(script_utilities.Utilities):
             lastObj, lastOffset = self.lastContext(math)
         else:
             lastObj, lastOffset = line[-1][0], line[-1][2] - 1
-        msg = "INFO: Last context on line is: %s, %i" % (lastObj, lastOffset)
+        msg = "WEB: Last context on line is: %s, %i" % (lastObj, lastOffset)
         debug.println(debug.LEVEL_INFO, msg)
 
         obj, offset = self.nextContext(lastObj, lastOffset, True)
-        msg = "INFO: Next context is: %s, %i" % (obj, offset)
+        if not obj and lastObj:
+            msg = "WEB: Next context is: %s, %i. Trying again." % (obj, offset)
+            debug.println(debug.LEVEL_INFO, msg)
+            self.clearCachedObjects()
+            obj, offset = self.nextContext(lastObj, lastOffset, True)
+
+        msg = "WEB: Next context is: %s, %i" % (obj, offset)
         debug.println(debug.LEVEL_INFO, msg)
 
         contents = self.getLineContentsAtOffset(obj, offset, layoutMode, useCache)
         if not contents:
-            msg = "INFO: Could not get line contents for %s, %i" % (obj, offset)
+            msg = "WEB: Could not get line contents for %s, %i" % (obj, offset)
             debug.println(debug.LEVEL_INFO, msg)
             return []
 
@@ -1175,6 +1227,8 @@ class Utilities(script_utilities.Utilities):
             role = obj.getRole()
             state = obj.getState()
         except:
+            msg = "WEB: Exception getting role and state for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
             return False
 
         if state.contains(pyatspi.STATE_EDITABLE) \
@@ -1218,8 +1272,14 @@ class Utilities(script_utilities.Utilities):
         if rv is not None:
             return rv
 
-        role = obj.getRole()
-        state = obj.getState()
+        try:
+            role = obj.getRole()
+            state = obj.getState()
+        except:
+            msg = "WEB: Exception getting role and state for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
+            return False
+
         textBlockElements = [pyatspi.ROLE_CAPTION,
                              pyatspi.ROLE_COLUMN_HEADER,
                              pyatspi.ROLE_DOCUMENT_FRAME,
@@ -1237,6 +1297,12 @@ class Utilities(script_utilities.Utilities):
                              pyatspi.ROLE_TEXT,
                              pyatspi.ROLE_TABLE_CELL]
 
+        # TODO - JD: This protection won't be needed once we bump dependencies to 2.16.
+        try:
+            textBlockElements.append(pyatspi.ROLE_STATIC)
+        except:
+            pass
+
         if not role in textBlockElements:
             rv = False
         elif state.contains(pyatspi.STATE_EDITABLE):
@@ -1251,6 +1317,26 @@ class Utilities(script_utilities.Utilities):
         self._isTextBlockElement[hash(obj)] = rv
         return rv
 
+    def treatAsDiv(self, obj):
+        rv = self._treatAsDiv.get(hash(obj))
+        if rv is not None:
+            return rv
+
+        try:
+            role = obj.getRole()
+            childCount = obj.childCount
+        except:
+            msg = "WEB: Exception getting role and childCount for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
+            return False
+
+        rv = False
+        if role == pyatspi.ROLE_LIST:
+            rv = not (childCount and obj[0].getRole() == pyatspi.ROLE_LIST_ITEM)
+
+        self._treatAsDiv[hash(obj)] = rv
+        return rv
+
     def speakMathSymbolNames(self, obj=None):
         obj = obj or orca_state.locusOfFocus
         return self.isMath(obj)
@@ -1565,6 +1651,7 @@ class Utilities(script_utilities.Utilities):
                or self.isAnchor(obj) \
                or self.hasNoSize(obj) \
                or self.isOffScreenLabel(obj) \
+               or self.isUselessImage(obj) \
                or self.isLabellingContents(x, contents):
                 return False
 
@@ -1769,6 +1856,14 @@ class Utilities(script_utilities.Utilities):
             return rv
 
         role = obj.getRole()
+
+        # TODO - JD: This protection won't be needed once we bump dependencies to 2.16.
+        try:
+            if role == pyatspi.ROLE_STATIC:
+                role = pyatspi.ROLE_TEXT
+        except:
+            pass
+
         if role == pyatspi.ROLE_LINK and not self.isAnchor(obj):
             rv = True
         elif role == pyatspi.ROLE_TEXT \
@@ -1794,6 +1889,37 @@ class Utilities(script_utilities.Utilities):
         self._isNonNavigablePopup[hash(obj)] = rv
         return rv
 
+    def isUselessImage(self, obj):
+        if not (obj and self.inDocumentContent(obj)):
+            return False
+
+        rv = self._isUselessImage.get(hash(obj))
+        if rv is not None:
+            return rv
+
+        rv = True
+        if obj.getRole() != pyatspi.ROLE_IMAGE:
+            rv = False
+        if rv and (obj.name or obj.description or obj.childCount):
+            rv = False
+        if rv and (self.isClickableElement(obj) or self.hasLongDesc(obj)):
+            rv = False
+        if rv and obj.parent.getRole() == pyatspi.ROLE_LINK:
+            uri = self.uri(obj.parent)
+            if uri and not uri.startswith('javascript'):
+                rv = False
+        if rv and 'Image' in pyatspi.listInterfaces(obj):
+            image = obj.queryImage()
+            if image.imageDescription:
+                rv = False
+            else:
+                width, height = image.getImageSize()
+                if width > 25 and height > 25:
+                    rv = False
+
+        self._isUselessImage[hash(obj)] = rv
+        return rv
+
     def hasLongDesc(self, obj):
         if not (obj and self.inDocumentContent(obj)):
             return False
@@ -1826,8 +1952,14 @@ class Utilities(script_utilities.Utilities):
         return rv
 
     def shouldInferLabelFor(self, obj):
-        if obj.name:
-            return False
+        try:
+            name = obj.name
+        except:
+            msg = "WEB: Exception getting name for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
+        else:
+            if name:
+                return False
 
         if self._script.inSayAll():
             return False
@@ -1835,7 +1967,12 @@ class Utilities(script_utilities.Utilities):
         if not self.inDocumentContent():
             return False
 
-        role = obj.getRole()
+        try:
+            role = obj.getRole()
+        except:
+            msg = "WEB: Exception getting role for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
+            return False
 
         # TODO - JD: This is private.
         if self._script._lastCommandWasCaretNav \
@@ -1996,7 +2133,13 @@ class Utilities(script_utilities.Utilities):
     def getChildIndex(obj, offset):
         try:
             hypertext = obj.queryHypertext()
+        except NotImplementedError:
+            msg = "WEB: %s does not implement the hypertext interface" % obj
+            debug.println(debug.LEVEL_INFO, msg)
+            return -1
         except:
+            msg = "WEB: Exception querying hypertext interface for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
             return -1
 
         return hypertext.getLinkIndex(offset)
@@ -2035,6 +2178,15 @@ class Utilities(script_utilities.Utilities):
         if not obj or self.isZombie(obj):
             return True
 
+        try:
+            childCount = obj.childCount
+        except:
+            msg = "WEB: Exception getting childCount for %s" % obj
+            debug.println(debug.LEVEL_INFO, msg)
+            return True
+        if not childCount:
+            return True
+
         if self.isHidden(obj) or self.isOffScreenLabel(obj):
             return True
 
@@ -2180,11 +2332,12 @@ class Utilities(script_utilities.Utilities):
                 allText = text.getText(0, -1)
                 for i in range(offset + 1, len(allText)):
                     child = self.getChildAtOffset(obj, i)
-                    if child and not self.isZombie(child) and not self.isAnchor(child):
+                    if child and not self.isZombie(child) and not self.isAnchor(child) \
+                       and not self.isUselessImage(child):
                         return self.findNextCaretInOrder(child, -1)
                     if allText[i] != self.EMBEDDED_OBJECT_CHARACTER:
                         return obj, i
-            elif obj.childCount and not self.doNotDescendForCaret(obj):
+            elif not self.doNotDescendForCaret(obj) and obj.childCount:
                 return self.findNextCaretInOrder(obj[0], -1)
             elif offset < 0 and not self.isTextBlockElement(obj) and not self.hasNoSize(obj):
                 return obj, 0
@@ -2211,8 +2364,14 @@ class Utilities(script_utilities.Utilities):
                 return self.findNextCaretInOrder(parent, start)
 
             index = obj.getIndexInParent() + 1
-            if 0 <= index < parent.childCount:
-                return self.findNextCaretInOrder(parent[index], -1)
+            try:
+                parentChildCount = parent.childCount
+            except:
+                msg = "WEB: Exception getting childCount for %s" % parent
+                debug.println(debug.LEVEL_INFO, msg)
+            else:
+                if 0 <= index < parentChildCount:
+                    return self.findNextCaretInOrder(parent[index], -1)
             obj = parent
 
         return None, -1
@@ -2232,11 +2391,12 @@ class Utilities(script_utilities.Utilities):
                     offset = len(allText)
                 for i in range(offset - 1, -1, -1):
                     child = self.getChildAtOffset(obj, i)
-                    if child and not self.isZombie(child) and not self.isAnchor(child):
+                    if child and not self.isZombie(child) and not self.isAnchor(child) \
+                       and not self.isUselessImage(child):
                         return self.findPreviousCaretInOrder(child, -1)
                     if allText[i] != self.EMBEDDED_OBJECT_CHARACTER:
                         return obj, i
-            elif obj.childCount and not self.doNotDescendForCaret(obj):
+            elif not self.doNotDescendForCaret(obj) and obj.childCount:
                 return self.findPreviousCaretInOrder(obj[obj.childCount - 1], -1)
             elif offset < 0 and not self.isTextBlockElement(obj) and not self.hasNoSize(obj):
                 return obj, 0
@@ -2263,8 +2423,14 @@ class Utilities(script_utilities.Utilities):
                 return self.findPreviousCaretInOrder(parent, start)
 
             index = obj.getIndexInParent() - 1
-            if 0 <= index < parent.childCount:
-                return self.findPreviousCaretInOrder(parent[index], -1)
+            try:
+                parentChildCount = parent.childCount
+            except:
+                msg = "WEB: Exception getting childCount for %s" % parent
+                debug.println(debug.LEVEL_INFO, msg)
+            else:
+                if 0 <= index < parentChildCount:
+                    return self.findPreviousCaretInOrder(parent[index], -1)
             obj = parent
 
         return None, -1
