@@ -467,10 +467,8 @@ class SpeechGenerator(generator.Generator):
 
         result = []
         acss = self.voice(STATE)
-        if obj.getState().contains(pyatspi.STATE_MULTISELECTABLE):
-            # Translators: "multi-select" refers to a web form list
-            # in which more than one item can be selected at a time.
-            #
+        if obj.getState().contains(pyatspi.STATE_MULTISELECTABLE) \
+           and obj.childCount:
             result.append(self._script.formatting.getString(
                 mode='speech',
                 stringType='multiselect'))
@@ -1466,6 +1464,9 @@ class SpeechGenerator(generator.Generator):
             if not items and obj.childCount:
                 items.append(obj[0])
 
+        if not (items and items[0]):
+            return result
+
         items = list(map(self._generateName, items))
         for item in items:
             result.extend(item)
@@ -1857,10 +1858,12 @@ class SpeechGenerator(generator.Generator):
         acss = self.voice(SYSTEM)
         alreadyFocused = args.get('alreadyFocused', False)
         forceTutorial = args.get('forceTutorial', False)
+        role = args.get('role', obj.getRole())
         result.extend(self._script.tutorialGenerator.getTutorial(
                 obj,
                 alreadyFocused,
-                forceTutorial))
+                forceTutorial,
+                role))
         if args.get('role', obj.getRole()) == pyatspi.ROLE_ICON \
             and args.get('formatType', 'unfocused') == 'basicWhereAmI':
             frame, dialog = self._script.utilities.frameAndDialog(obj)
