@@ -37,6 +37,7 @@ __license__   = "LGPL"
 
 from gi.repository import GLib
 import re
+import time
 
 from . import chnames
 from . import debug
@@ -160,6 +161,8 @@ class SpeechServer(speechserver.SpeechServer):
         else:
             SpeechServer._active_servers[serverId] = self
 
+        self._lastKeyEchoTime = None
+
     def _init(self):
         self._client = client = speechd.SSIPClient('Orca', component=self._id)
         client.set_priority(speechd.Priority.MESSAGE)
@@ -365,6 +368,20 @@ class SpeechServer(speechserver.SpeechServer):
         self.speak(decrease and messages.SPEECH_LOWER \
                    or messages.SPEECH_HIGHER, acss=acss)
 
+    def _change_default_speech_volume(self, step, decrease=False):
+        acss = settings.voices[settings.DEFAULT_VOICE]
+        delta = step * (decrease and -1 or +1)
+        try:
+            volume = acss[ACSS.GAIN]
+        except KeyError:
+            volume = 5
+        acss[ACSS.GAIN] = max(0, min(9, volume + delta))
+        debug.println(debug.LEVEL_CONFIGURATION,
+                      "Speech volume is now %d" % volume)
+
+        self.speak(decrease and messages.SPEECH_SOFTER \
+                   or messages.SPEECH_LOUDER, acss=acss)
+
     def getInfo(self):
         return [self._SERVER_NAMES.get(self._id, self._id), self._id]
 
@@ -401,6 +418,13 @@ class SpeechServer(speechserver.SpeechServer):
         #if interrupt:
         #    self._cancel()
 
+        # "We will not interrupt a key echo in progress." (Said the comment in
+        # speech.py where these next two lines used to live. But the code here
+        # suggests we haven't been doing anything with the lastKeyEchoTime in
+        # years. TODO - JD: Dig into this and if it's truly useless, kill it.)
+        if self._lastKeyEchoTime:
+            interrupt = interrupt and (time.time() - self._lastKeyEchoTime) > 0.5
+
         if text:
             self._speak(text, acss)
 
@@ -444,6 +468,7 @@ class SpeechServer(speechserver.SpeechServer):
         lockingStateString = event.getLockingStateString()
         event_string = "%s %s" % (event_string, lockingStateString)
         self.speak(event_string, acss=acss)
+        self._lastKeyEchoTime = time.time()
 
     def increaseSpeechRate(self, step=5):
         self._change_default_speech_rate(step)
@@ -457,6 +482,12 @@ class SpeechServer(speechserver.SpeechServer):
     def decreaseSpeechPitch(self, step=0.5):
         self._change_default_speech_pitch(step, decrease=True)
 
+    def increaseSpeechVolume(self, step=0.5):
+        self._change_default_speech_volume(step)
+
+    def decreaseSpeechVolume(self, step=0.5):
+        self._change_default_speech_volume(step, decrease=True)
+
     def stop(self):
         self._cancel()
 
